@@ -3,6 +3,7 @@ import sys, traceback
 from types import ModuleType
 from typing import Tuple, Union
 from importlib.resources import read_text
+import traceback
 
 import argparse
 from prompt_toolkit.shortcuts.prompt import PromptSession
@@ -374,7 +375,8 @@ def eval_sexp(sexp, env):
                     for exp in sexp[1:]:
                         res = eval_sexp(exp, env)
                     return res
-                except:
+                except Exception as e:
+                    env.set(Symbol("*error*"), e)
                     return eval_sexp(sexp['catch'], env)
                 finally:
                     eval_sexp(sexp['finally'], env)
@@ -384,7 +386,8 @@ def eval_sexp(sexp, env):
                     for exp in sexp[1:]:
                         res = eval_sexp(exp, env)
                     return res
-                except:
+                except Exception as e:
+                    env.set(Symbol("*error*"), e)
                     return eval_sexp(sexp['catch'], env)
             elif Keyword('finally') in sexp:
                 try:
@@ -401,7 +404,7 @@ def eval_sexp(sexp, env):
                 return res
         # ns stuff #
         elif is_s and "ns" == head.name:
-            ns_name = sexp.positional[1].name           
+            ns_name = sexp.positional[1].name
             if ns_name not in loaded_ns:
                 if env.ns.name == "":
                     # it means the execution is not currently happening in an environment:
@@ -417,14 +420,6 @@ def eval_sexp(sexp, env):
             # requires/refers other namespaces and vars as specified
             # dadi
             break
-        elif is_s and "in-ns" == head.name:
-            ns_name = sexp.positional[1][1].name
-            if ns_name not in loaded_ns:
-                eval_sexp(read_sexp(f"(ns {ns_name})"), env)
-            else:
-                # this doesn't seem to work
-                env = loaded_ns[ns_name]
-            break
         elif is_s and "require" == head.name:
             require([sexp.positional[1].name], env.ns)
             break
